==> seedsui-react-5.7.84.tgz: package/lib/Select/Main/Item.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["item", "index", "checkedType", "checkedPosition", "disabled", "checked", "checkable", "onClick"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Item = function Item(_ref) {
  var item = _ref.item,
    index = _ref.index,
    _ref$checkedType = _ref.checkedType,
    checkedType = _ref$checkedType === void 0 ? 'checkbox' : _ref$checkedType,
    _ref$checkedPosition = _ref.checkedPosition,
    checkedPosition = _ref$checkedPosition === void 0 ? 'right' : _ref$checkedPosition,
    disabled = _ref.disabled,
    checked = _ref.checked,
    checkable = _ref.checkable,
    onClick = _ref.onClick,
    props = _objectWithoutProperties(_ref, _excluded);
  // 获取checkType
  function getCheckedType() {
    return typeof checkedType === 'string' ? checkedType : 'checkbox';
  }
  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({}, props), {}, {
    className: "select-option".concat(props.className ? ' ' + props.className : '').concat(disabled ? ' disabled' : '').concat(checked ? ' active' : ''),
    "checked-position": checkedPosition === 'left' ? 'left' : 'right',
    "checked-type": getCheckedType(),
    "data-index": index,
    onClick: onClick,
    children: [checkable !== false && /*#__PURE__*/_jsx("div", {
      className: "left select-option-".concat(getCheckedType()),
      children: /*#__PURE__*/_jsx("div", {
        className: "checked-input"
      })
    }), /*#__PURE__*/_jsxs("div", {
      className: "select-option-content",
      children: [/*#__PURE__*/_jsx("p", {
        className: "select-option-caption",
        children: item.name
      }), item.description && /*#__PURE__*/_jsx("div", {
        className: "select-option-description",
        children: item.description
      })]
    }), checkable !== false && /*#__PURE__*/_jsx("div", {
      className: "right select-option-".concat(getCheckedType()),
      children: /*#__PURE__*/_jsx("div", {
        className: "checked-input"
      })
    })]
  }));
};
export default Item;

==> seedsui-react-5.8.44.tgz: package/lib/Select/Main/Item.js <==
var _excluded = ["item", "index", "checkedType", "checkedPosition", "disabled", "checked", "checkable", "onClick"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
var Item = function Item(_ref) {
  var item = _ref.item,
    index = _ref.index,
    _ref$checkedType = _ref.checkedType,
    checkedType = _ref$checkedType === void 0 ? 'checkbox' : _ref$checkedType,
    _ref$checkedPosition = _ref.checkedPosition,
    checkedPosition = _ref$checkedPosition === void 0 ? 'right' : _ref$checkedPosition,
    disabled = _ref.disabled,
    checked = _ref.checked,
    checkable = _ref.checkable,
    onClick = _ref.onClick,
    props = _objectWithoutProperties(_ref, _excluded);
  // 获取checkType
  function getCheckedType() {
    return typeof checkedType === 'string' ? checkedType : 'checkbox';
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: "select-option".concat(props.className ? ' ' + props.className : '').concat(disabled ? ' disabled' : '').concat(checked ? ' active' : ''),
    "checked-position": checkedPosition === 'left' ? 'left' : 'right',
    "checked-type": getCheckedType(),
    "data-index": index,
    onClick: onClick
  }), checkable !== false && /*#__PURE__*/React.createElement("div", {
    className: "left select-option-".concat(getCheckedType())
  }, /*#__PURE__*/React.createElement("div", {
    className: "checked-input"
  })), /*#__PURE__*/React.createElement("div", {
    className: "select-option-content"
  }, /*#__PURE__*/React.createElement("p", {
    className: "select-option-caption"
  }, item.name), item.description && /*#__PURE__*/React.createElement("div", {
    className: "select-option-description"
  }, item.description)), checkable !== false && /*#__PURE__*/React.createElement("div", {
    className: "right select-option-".concat(getCheckedType())
  }, /*#__PURE__*/React.createElement("div", {
    className: "checked-input"
  })));
};
export default Item;
